# arpes.utilities.attrs module

**arpes.utilities.attrs.diff\_attrs(a:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
b: Union\[xarray.core.dataarray.DataArray,
xarray.core.dataset.Dataset\], should\_print=True, skip\_nan=False,
skip\_composite=True)**
